Struct ngyn_shared::server::context::NgynContext

source ·
pub struct NgynContext { /* private fields */ }
Represents the context of a request in Ngyn

Implementations

source

impl NgynContext

source

pub fn request(&self) -> &Request<Vec<u8>>

Retrieves the request associated with the context.

Returns

A reference to the request associated with the context.

Examples
use ngyn_shared::core::context::NgynContext;
use hyper::Request;

let request = Request::new(Vec::new());
let context = NgynContext::from_request(request);

let request_ref = context.request();
source

pub fn params(&self) -> Option<&Vec<(String, String)>>

Retrieves the params associated with the context.

Returns

An optional reference to the params associated with the context.

Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set("name", "John".into());

let params_ref = context.params();
source

impl NgynContext

source

pub fn state<T: 'static>(&self) -> Option<&T>

Retrieves the state of the context as a reference to the specified type.

Type Parameters
  • T - The type of the state to retrieve.
Returns

An optional reference to the state of the specified type. Returns None if the state is not found or if it cannot be downcasted to the specified type.

Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set_state(Box::new(MyAppState::new()));

let state_ref = context.state::<MyAppState>();
source

impl NgynContext

source

pub fn get<V: for<'a> Deserialize<'a>>(&self, key: &str) -> Option<V>

Retrieves the value associated with the given key from the context.

Arguments
  • key - The key to retrieve the value for.
Returns

A reference to the value associated with the key. If the key is not found, returns a reference to an empty context value.

Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set("name", "John".into());

let value: String = context.get("name").unwrap();
assert_eq!(value, "John".to_string());
source

pub fn set<V: Serialize>(&mut self, key: &str, value: V)

Sets the value associated with the given key in the context.

Arguments
  • key - The key to set the value for.
  • value - The value to associate with the key.
Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set("name", "John".into());

let value: String = context.get("name").unwrap();
assert_eq!(value, "John".to_string());
source

pub fn remove(&mut self, key: &str)

Removes the value associated with the given key from the context.

Arguments
  • key - The key to remove the value for.
Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set("name", "John".into());

context.remove("name");
let value = context.get::<String>("name");
assert_eq!(value, None);
source

pub fn clear(&mut self)

Clears all values from the context.

Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set("name", "John".into());
context.set("age", 30.into());

context.clear();
assert_eq!(context.len(), 0);
source

pub fn len(&self) -> usize

Returns the number of values in the context.

Returns

The number of values in the context.

Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set("name", "John".into());
context.set("age", 30.into());

assert_eq!(context.len(), 2);
source

pub fn is_empty(&self) -> bool

Checks if the context is empty.

Returns

true if the context is empty, false otherwise.

Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);

assert!(context.is_empty());

context.set("name", "John".into());
assert!(!context.is_empty());
source

pub fn has(&self, key: &str) -> bool

Checks if the context contains a value for the given key.

Arguments
  • key - The key to check for.
Returns

true if the context contains a value for the key, false otherwise.

Examples
use ngyn_shared::core::context::NgynContext;

let mut context = NgynContext::from_request(request);
context.set("name", "John".into());

assert!(context.has("name"));
assert!(!context.has("age"));
source

impl NgynContext

source

pub fn is_valid_route(&self) -> bool

Checks if the context has a valid route. A valid route is when the route information and the params are set. This is great for differentiating known routes from unknown routes.

Returns

true if the context has a valid route, false otherwise.