Module ngyn_shared::traits

source ·

Traits

  • AsAny is an extra thread-safe trait implemented by all injectables.
  • NgynController defines the basic structure of a controller in Ngyn. It is designed to be thread-safe.
  • NgynControllerHandler is an internal trait that defines placeholders for routing logic of a controller.
  • Trait for implementing a gate.
  • NgynInjectable is a thread-safe trait that defines the basic structure of an injectable in Ngyn.
  • Trait for implementing a middleware.
  • NgynModule is a trait that defines the basic structure of a module in Ngyn.